@@ -99,7 +99,6 @@ EC2 instance that simulate the vehicle. Once deploy is finshed, data will start
 
 Warning: this construct should be considered at alpha stage and is not feature complete.
 
-* Apply the least priviledge principle to roles
 * Implement updates for all the custom resources
 * Conditional campaigns
 
@@ -126,8 +125,6 @@ from ._jsii import *
 
 import aws_cdk
 import aws_cdk.aws_iam
-import aws_cdk.aws_lambda
-import aws_cdk.aws_logs
 import aws_cdk.aws_timestream
 import constructs
 
@@ -497,21 +494,6 @@ class SignalCatalog(
     def arn(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "arn"))
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="lambdaLayer")
-    def lambda_layer(self) -> aws_cdk.aws_lambda.LayerVersion:
-        return typing.cast(aws_cdk.aws_lambda.LayerVersion, jsii.get(self, "lambdaLayer"))
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="lambdaRole")
-    def lambda_role(self) -> aws_cdk.aws_iam.Role:
-        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "lambdaRole"))
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="logRetention")
-    def log_retention(self) -> aws_cdk.aws_logs.RetentionDays:
-        return typing.cast(aws_cdk.aws_logs.RetentionDays, jsii.get(self, "logRetention"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
