@@ -18,24 +18,42 @@ export class IntegTesting {
 
     const stack = new cdk.Stack(app, 'integ-stack', { env });
 
+    const databaseName = 'FleetWise';
+    const tableName = 'FleetWise';
+
     const database = new ts.CfnDatabase(stack, 'Database', {
-      databaseName: 'FleetWise',
+      databaseName,
     });
 
     const table = new ts.CfnTable(stack, 'Table', {
-      databaseName: 'FleetWise',
-      tableName: 'FleetWise',
+      databaseName,
+      tableName,
     });
 
     table.node.addDependency(database);
 
     const role = new iam.Role(stack, 'Role', {
+      roleName: 'iotfleetwise-role',
       assumedBy: new iam.ServicePrincipal('iotfleetwise.amazonaws.com'),
-      managedPolicies: [
-        iam.ManagedPolicy.fromAwsManagedPolicyName('AdministratorAccess'),
-      ],
     });
 
+    role.addToPolicy(new iam.PolicyStatement({
+      effect: iam.Effect.ALLOW,
+      actions: [
+        'timestream:WriteRecords',
+        'timestream:Select',
+      ],
+      resources: ['*'],
+    }));
+
+    role.addToPolicy(new iam.PolicyStatement({
+      effect: iam.Effect.ALLOW,
+      actions: [
+        'timestream:DescribeEndpoints',
+      ],
+      resources: ['*'],
+    }));
+
     const signalCatalog = new ifw.SignalCatalog(stack, 'SignalCatalog', {
       database,
       table,
@@ -69,7 +87,13 @@ export class IntegTesting {
       vehicleModel: model_a,
       createIotThing: true,
     });
-    new cdk.CfnOutput(stack, 'certificateId', { value: vin100.certificateId! });
+
+    const vin200 = new ifw.Vehicle(stack, 'vin200', {
+      vehicleId: 'vin200',
+      vehicleModel: model_a,
+      createIotThing: true,
+    });
+
 
     new ifw.Campaign(stack, 'Campaign1', {
       name: 'FwTimeBasedCampaign1',
@@ -81,6 +105,12 @@ export class IntegTesting {
       autoApprove: true,
     });
 
+    new ifw.Fleet(stack, 'Fleet1', {
+      fleetId: 'fleet1',
+      signalCatalog,
+      vehicles: [vin100, vin200],
+    });
+
     new ifw.Fleet(stack, 'Fleet2', {
       fleetId: 'fleet2',
       signalCatalog,
@@ -91,7 +121,4 @@ export class IntegTesting {
   }
 }
 
-process.env.GITLAB_REGISTRATION_TOKEN='mock';
-process.env.CDK_INTEG_REGION='eu-central-1';
-
 new IntegTesting();
\ No newline at end of file
