@@ -1,13 +1,12 @@
-import * as path from 'path';
 import * as cdk from 'aws-cdk-lib';
 import {
   aws_iam as iam,
   aws_timestream as ts,
-  aws_lambda as lambda,
-  aws_logs as logs,
-  custom_resources as cr,
 } from 'aws-cdk-lib';
 import { Construct } from 'constructs';
+import { Handler } from './handler';
+import { Provider } from './provider';
+
 
 export class SignalCatalogNode {
   protected node: object;
@@ -92,64 +91,35 @@ export class SignalCatalog extends Construct {
   readonly name: string;
   readonly description: (string|undefined);
   readonly arn: string;
-  readonly lambdaRole: iam.Role;
-  readonly lambdaLayer: lambda.LayerVersion;
-  readonly logRetention: logs.RetentionDays;
 
   constructor(scope: Construct, id: string, props: SignalCatalogProps) {
     super(scope, id);
 
-
     this.name = props.name || 'default';
     this.description = props.description;
     this.arn = `arn:aws:iotfleetwise:${cdk.Aws.REGION}:${cdk.Aws.ACCOUNT_ID}:signal-catalog/${this.name}`;
 
-    this.lambdaRole = new iam.Role(this, 'Role', {
-      assumedBy: new iam.ServicePrincipal('lambda.amazonaws.com'),
-      managedPolicies: [
-        iam.ManagedPolicy.fromAwsManagedPolicyName('service-role/AWSLambdaBasicExecutionRole'),
-        iam.ManagedPolicy.fromAwsManagedPolicyName('AdministratorAccess'),
-      ],
-    });
-
-    this.lambdaLayer = new lambda.LayerVersion(this, 'Boto3', {
-      description: 'Boto3 Library with Iot Fleetwise Support',
-      compatibleRuntimes: [lambda.Runtime.PYTHON_3_9],
-      code: lambda.AssetCode.fromAsset(path.join(__dirname, '/../layer.zip')),
-    });
-
-    const code = lambda.AssetCode.fromAsset(path.join(__dirname, '/../src/handlers'));
-
-    this.logRetention = logs.RetentionDays.ONE_DAY;
-
-    const onEventHandlerService = new lambda.Function(this, 'Service', {
-      code,
+    const handler = new Handler(this, 'Handler', {
       handler: 'servicehandler.on_event',
-      timeout: cdk.Duration.seconds(300),
-      runtime: lambda.Runtime.PYTHON_3_9,
-      layers: [this.lambdaLayer],
-      role: this.lambdaRole,
-      logRetention: this.logRetention,
     });
 
-    const isCompleteHandlerService = new lambda.Function(this, 'ServiceComplete', {
-      code,
+    const isCompleteHandler = new Handler(this, 'IsCompleteHandler', {
       handler: 'servicehandler.is_complete',
-      timeout: cdk.Duration.seconds(300),
-      runtime: lambda.Runtime.PYTHON_3_9,
-      layers: [this.lambdaLayer],
-      role: this.lambdaRole,
-      logRetention: this.logRetention,
     });
 
-    const providerService = new cr.Provider(this, 'ServiceProvider', {
-      onEventHandler: onEventHandlerService,
-      isCompleteHandler: isCompleteHandlerService,
-      logRetention: this.logRetention,
-    });
+
+    handler.role!.addToPrincipalPolicy(new iam.PolicyStatement({
+      effect: iam.Effect.ALLOW,
+      actions: [
+        'iam:PassRole',
+      ],
+      resources: [props.role.roleArn],
+    }));
+
+    const provider = Provider.getOrCreate(this, handler, isCompleteHandler);
 
     const serviceResource = new cdk.CustomResource(this, 'ServiceResource', {
-      serviceToken: providerService.serviceToken,
+      serviceToken: provider.provider.serviceToken,
       properties: {
         role_arn: props.role.roleArn,
         database_name: props.database.databaseName,
@@ -157,23 +127,12 @@ export class SignalCatalog extends Construct {
       },
     });
 
-    const onEventHandlerCatalog = new lambda.Function(this, 'Catalog', {
-      code,
+    const serviceCatalogHandler = new Handler(this, 'ServiceCatalogHandler', {
       handler: 'signalcataloghandler.on_event',
-      timeout: cdk.Duration.seconds(300),
-      runtime: lambda.Runtime.PYTHON_3_9,
-      layers: [this.lambdaLayer],
-      role: this.lambdaRole,
-      logRetention: this.logRetention,
-    });
-
-    const providerCatalog = new cr.Provider(this, 'CatalogProvider', {
-      onEventHandler: onEventHandlerCatalog,
-      logRetention: this.logRetention,
     });
 
     const resourceCatalog = new cdk.CustomResource(this, 'CatalogResource', {
-      serviceToken: providerCatalog.serviceToken,
+      serviceToken: Provider.getOrCreate(this, serviceCatalogHandler).provider.serviceToken,
       properties: {
         name: this.name,
         description: this.description,
