@@ -1,10 +1,7 @@
-import * as path from 'path';
 import * as cdk from 'aws-cdk-lib';
-import {
-  aws_lambda as lambda,
-  custom_resources as cr,
-} from 'aws-cdk-lib';
 import { Construct } from 'constructs';
+import { Handler } from './handler';
+import { Provider } from './provider';
 import { SignalCatalog } from './signalcatalog';
 
 export class VehicleInterface {
@@ -132,23 +129,12 @@ export class VehicleModel extends Construct {
     (this.name as string) = props.name || '';
     (this.signalCatalog as SignalCatalog) = props.signalCatalog;
 
-    const onEventHandler = new lambda.Function(this, 'Lambda', {
-      code: lambda.AssetCode.fromAsset(path.join(__dirname, '/../src/handlers')),
+    const handler = new Handler(this, 'Handler', {
       handler: 'vehiclemodelhandler.on_event',
-      timeout: cdk.Duration.seconds(300),
-      runtime: lambda.Runtime.PYTHON_3_9,
-      layers: [this.signalCatalog.lambdaLayer],
-      role: this.signalCatalog.lambdaRole,
-      logRetention: this.signalCatalog.logRetention,
-    });
-
-    const provider = new cr.Provider(this, 'Provider', {
-      onEventHandler: onEventHandler,
-      logRetention: this.signalCatalog.logRetention,
     });
 
     const resource = new cdk.CustomResource(this, 'Resource', {
-      serviceToken: provider.serviceToken,
+      serviceToken: Provider.getOrCreate(this, handler).provider.serviceToken,
       properties: {
         name: this.name,
         signal_catalog_arn: props.signalCatalog.arn,
